@@ -22,6 +22,10 @@ iconDir26x26="debian/tmp/usr/share/icons/hicolor/26x26/hildon/"
 mkdir -p $iconDir26x26
 cp gfx/icon_26x26.png $iconDir26x26/theremin.png
 
+#=======================================
+#=====Package name======================
+#=======================================
+packageName="theremin_1.8.1-2_armel.deb"
 
 
 #create dir where the output 'control' will be placed
@@ -30,7 +34,10 @@ mkdir -p debian/tmp/DEBIAN
 #calculate dependancies
 dpkg-shlibdeps $binDir/theremin
 
+#optify
+maemo-optify $packageName debian/tmp
+
 #generate final control file
 dpkg-gencontrol
 
-dpkg -b debian/tmp ../theremin_1.8.1-1_armel.deb
+dpkg -b debian/tmp ../$packageName
