@@ -18,13 +18,13 @@
 //forward declarations
 class Client;
 
+typedef std::list<ting::Ref<Client> > T_ClientsList;
+typedef T_ClientsList::iterator T_ClientsIter;
 
 class Cast{
 	ting::Ref<Client> player;
 
-	typedef std::list<ting::Ref<Client> > T_ListenersList;
-	typedef T_ListenersList::iterator T_ListenersIter;
-	T_ListenersList listeners;
+	T_ClientsList listeners;
 
 	ting::Array<ting::byte> bufferedChunk;
 
