@@ -33,7 +33,7 @@ THE SOFTWARE. */
 BasicWindow::BasicWindow(bool rootWindow) :
 		isRootWindow(rootWindow),
 		isFullscreen(false),
-		optionsMenuItem("Options")
+		optionsMenuItem("Settings")
 {
 	this->set_default_size(800, 480);
 
