@@ -84,10 +84,16 @@ MainWindow::MainWindow() :
 				sigc::mem_fun(*this, &MainWindow::ShowThereminScreen)
 			);
 
-		Gtk::Button *nb = new Gtk::Button("Network settings");
-		vbox->add(*Gtk::manage(nb));
-		nb->signal_clicked().connect(
-				sigc::mem_fun(*this, &MainWindow::ShowNetworkSettingsDialog)
+		Gtk::Button *ab = new Gtk::Button("Anglephone");
+		vbox->add(*Gtk::manage(ab));
+		ab->signal_clicked().connect(
+				sigc::mem_fun(*this, &MainWindow::ShowAnglephoneScreen)
+			);
+
+		Gtk::Button *kb = new Gtk::Button("Keyboard");
+		vbox->add(*Gtk::manage(kb));
+		kb->signal_clicked().connect(
+				sigc::mem_fun(*this, &MainWindow::ShowKeyboardScreen)
 			);
 	}
 
@@ -95,17 +101,17 @@ MainWindow::MainWindow() :
 		Gtk::VBox *vbox = new Gtk::VBox();
 		hbox->add(*Gtk::manage(vbox));
 
-		Gtk::Button *kb = new Gtk::Button("Keyboard");
-		vbox->add(*Gtk::manage(kb));
-		kb->signal_clicked().connect(
-				sigc::mem_fun(*this, &MainWindow::ShowKeyboardScreen)
-			);
-
 		Gtk::Button *lb = new Gtk::Button("Listen others");
 		vbox->add(*Gtk::manage(lb));
 		lb->signal_clicked().connect(
 				sigc::mem_fun(*this, &MainWindow::ShowListenOthersScreen)
 			);
+
+		Gtk::Button *nb = new Gtk::Button("Network settings");
+		vbox->add(*Gtk::manage(nb));
+		nb->signal_clicked().connect(
+				sigc::mem_fun(*this, &MainWindow::ShowNetworkSettingsDialog)
+			);
 	}
 
 	{
