@@ -48,6 +48,7 @@ THE SOFTWARE. */
 #include "BasicWindow.hpp"
 #include "ThereminWindow.hpp"
 #include "KeyboardWindow.hpp"
+#include "AnglephoneWindow.hpp"
 #include "ListenWindow.hpp"
 #include "Preferences.hpp"
 
@@ -64,7 +65,7 @@ class MainWindow :
 	ThereminWindow thereminWindow;
 	ListenWindow listenWindow;
 	KeyboardWindow keyboardWindow;
-
+	AnglephoneWindow anglephoneWindow;
 
 public:
 	MainWindow();
@@ -87,6 +88,10 @@ public:
 		this->keyboardWindow.show();
 	}
 
+	void ShowAnglephoneScreen(){
+		this->anglephoneWindow.show();
+	}
+
 	void ShowNetworkSettingsDialog();
 	
 	void Exit();
