@@ -24,6 +24,7 @@ const char* DBroadcastAttribute = "broadcast";
 const char* DKeyboardTag = "Keyboard";
 const char* DScrPosAttribute = "scrPos";
 
+const char* DAnglephoneTag = "Anglephone";
 
 
 void Preferences::ClampBasePitch(){
@@ -57,6 +58,7 @@ void Preferences::LoadFromFile(){
 		doc.parse(reinterpret_cast<char*>(rawFile.Buf()));
 	}
 
+	//Load theremin mode settings
 	{
 		pugi::xml_node opts = doc.child(DThereminTag);
 		if(!opts.empty()){
@@ -84,6 +86,7 @@ void Preferences::LoadFromFile(){
 		}
 	}
 
+	//Load keyboard mode settings
 	{
 		pugi::xml_node kb = doc.child(DKeyboardTag);
 		if(!kb.empty()){
@@ -99,6 +102,17 @@ void Preferences::LoadFromFile(){
 		}
 	}
 
+	//Load anglephone mode settings
+	{
+		pugi::xml_node ang = doc.child(DAnglephoneTag);
+		if(!ang.empty()){
+			pugi::xml_attribute timbreAttr = ang.attribute(DTimbreAttribute);
+			if(!timbreAttr.empty()){
+				this->SetAngTimbre(TimbreNameToType(timbreAttr.value()));
+			}
+		}
+	}
+
 	//Read network settings
 	{
 		pugi::xml_node opts = doc.child(DNetworkOptionsTag);
@@ -137,6 +151,7 @@ void Preferences::SaveToFile(){
 		n.append_attribute("version").set_value("1.0");
 	}
 
+	//Save theremin mode settings
 	{
 		pugi::xml_node opts = doc.append_child();
 		opts.set_name(DThereminTag);
@@ -148,6 +163,7 @@ void Preferences::SaveToFile(){
 		opts.append_attribute(DBasePitchAttribute) = this->GetBasePitch();
 	}
 
+	//Save keyboard mode settings
 	{
 		pugi::xml_node kb = doc.append_child();
 		kb.set_name(DKeyboardTag);
@@ -157,6 +173,15 @@ void Preferences::SaveToFile(){
 			);
 	}
 
+	//Save anglemode mode settings
+	{
+		pugi::xml_node ang = doc.append_child();
+		ang.set_name(DAnglephoneTag);
+		ang.append_attribute(DTimbreAttribute).set_value(
+				TimbreTypeToName(this->GetAngTimbre()).c_str()
+			);
+	}
+
 	//Save network settings
 	{
 		pugi::xml_node ns = doc.append_child();//create NetworkSettings node
