@@ -24,12 +24,10 @@ THE SOFTWARE. */
  * aumiks 0.1
  */
 
-#ifndef M_config_hpp
-#define	M_config_hpp
+#pragma once
 
 namespace aumiks{
 
 typedef float real;
 
 }//~namespace
-#endif	//~once
